@@ -97,6 +97,16 @@ pub struct CheckResult {
     pub kind: String,
 }
 impl CheckResult {
+    pub fn invalid_err(kind: &str, interaction: &Interaction, text: &str) -> Self {
+        CheckResult {
+            request: interaction.request.clone(),
+            response: None,
+            violations: vec![],
+            duration: Some(Duration::new(0, 0)),
+            error: Some(text.to_string()),
+            kind: kind.to_string(),
+        }
+    }
     pub fn invalid(kind: &str, interaction: &Interaction) -> Self {
         CheckResult {
             request: interaction.request.clone(),
@@ -185,6 +195,8 @@ pub struct Interaction {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub response: Option<Response>,
     #[serde(skip_serializing_if = "Option::is_none")]
+    pub invalid: Option<Response>,
+    #[serde(skip_serializing_if = "Option::is_none")]
     pub examples: Option<HashMap<String, Response>>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub benchmark: Option<Benchmark>,
@@ -258,6 +270,14 @@ impl Interaction {
                 .map(|region| render_with_vars(region.clone(), &vars, &fmtstring));
         }
 
+        req.form = req.form.map(|mut vals| {
+            for val in vals.values_mut() {
+                let rendered = render_with_vars(val.clone(), &vars, &fmtstring);
+                *val = rendered;
+            }
+            vals
+        });
+
         // mising uri_list
         req.headers = req.headers.map(|mut headers| {
             for val in headers.values_mut() {
@@ -350,6 +370,7 @@ pub struct BasicAuth {
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct AWSAuth {
     pub region: Option<String>,
+    pub endpoint: Option<String>,
     pub service: String,
     pub key: String,
     pub secret: String,
